# История изменений

## 1.2.0 (2026-02-13)

- Убрана зависимость от pkg_resources

## 1.1.0 (2018-03-20)

- Добавлены сервисы асинхронного сбора показателей и запроса результата

## 1.0.1 (2018-01-23)

- Добавлена поддержка pip 10+

## 1.0.0 (2018-04-12)

- Добавлена поддержка python версии 3.6

## 0.1.4 (2018-01-31)

- Добавлен дополнительный необязательный параметр для показателя чтобы была возможность передать любой кастомный параметр влияющий на подсчет

## 0.1.3 (2017-02-14)

- Добавлена валидация параметров периода сбора показателей

## 0.1.2 (2016-09-23)

- Добавлены типы показателя по учреждениям

## 0.1.1 (2016-06-22)

- Включено сжатие данных (zip) в ответе на запрос

## 0.1.0 (2016-05-11)

- Сервис Аналитики ТО
